@@ -1,5 +1,4 @@
-use super::*;
-use std::time::Instant;
+use {super::*, std::time::Instant};
 
 #[derive(Default)]
 pub struct PurgeStats {
@@ -391,15 +390,17 @@ impl Blockstore {
 
 #[cfg(test)]
 pub mod tests {
-    use super::*;
-    use crate::{
-        blockstore::tests::make_slot_entries_with_transactions, entry::next_entry_mut,
-        get_tmp_ledger_path,
-    };
-    use bincode::serialize;
-    use solana_sdk::{
-        hash::{hash, Hash},
-        message::Message,
+    use {
+        super::*,
+        crate::{
+            blockstore::tests::make_slot_entries_with_transactions, entry::next_entry_mut,
+            get_tmp_ledger_path,
+        },
+        bincode::serialize,
+        solana_sdk::{
+            hash::{hash, Hash},
+            message::Message,
+        },
     };
 
     // check that all columns are either empty or start at `min_slot`
