@@ -1,38 +1,38 @@
-use crate::blockstore_meta;
-use bincode::{deserialize, serialize};
-use byteorder::{BigEndian, ByteOrder};
-use log::*;
-use prost::Message;
 pub use rocksdb::Direction as IteratorDirection;
-use rocksdb::{
-    self,
-    compaction_filter::CompactionFilter,
-    compaction_filter_factory::{CompactionFilterContext, CompactionFilterFactory},
-    ColumnFamily, ColumnFamilyDescriptor, CompactionDecision, DBIterator, DBRawIterator,
-    DBRecoveryMode, IteratorMode as RocksIteratorMode, Options, WriteBatch as RWriteBatch, DB,
-};
-
-use serde::de::DeserializeOwned;
-use serde::Serialize;
-use solana_runtime::hardened_unpack::UnpackError;
-use solana_sdk::{
-    clock::{Slot, UnixTimestamp},
-    pubkey::Pubkey,
-    signature::Signature,
-};
-use solana_storage_proto::convert::generated;
-use std::{
-    collections::{HashMap, HashSet},
-    ffi::{CStr, CString},
-    fs,
-    marker::PhantomData,
-    path::Path,
-    sync::{
-        atomic::{AtomicU64, Ordering},
-        Arc,
+use {
+    crate::blockstore_meta,
+    bincode::{deserialize, serialize},
+    byteorder::{BigEndian, ByteOrder},
+    log::*,
+    prost::Message,
+    rocksdb::{
+        self,
+        compaction_filter::CompactionFilter,
+        compaction_filter_factory::{CompactionFilterContext, CompactionFilterFactory},
+        ColumnFamily, ColumnFamilyDescriptor, CompactionDecision, DBIterator, DBRawIterator,
+        DBRecoveryMode, IteratorMode as RocksIteratorMode, Options, WriteBatch as RWriteBatch, DB,
     },
+    serde::{de::DeserializeOwned, Serialize},
+    solana_runtime::hardened_unpack::UnpackError,
+    solana_sdk::{
+        clock::{Slot, UnixTimestamp},
+        pubkey::Pubkey,
+        signature::Signature,
+    },
+    solana_storage_proto::convert::generated,
+    std::{
+        collections::{HashMap, HashSet},
+        ffi::{CStr, CString},
+        fs,
+        marker::PhantomData,
+        path::Path,
+        sync::{
+            atomic::{AtomicU64, Ordering},
+            Arc,
+        },
+    },
+    thiserror::Error,
 };
-use thiserror::Error;
 
 const MAX_WRITE_BUFFER_SIZE: u64 = 256 * 1024 * 1024; // 256MB
 
@@ -1430,8 +1430,7 @@ fn excludes_from_compaction(cf_name: &str) -> bool {
 
 #[cfg(test)]
 pub mod tests {
-    use super::*;
-    use crate::blockstore_db::columns::ShredData;
+    use {super::*, crate::blockstore_db::columns::ShredData};
 
     #[test]
     fn test_compaction_filter() {
