@@ -1,8 +1,10 @@
-use solana_runtime::{
-    bank::{Builtin, Builtins},
-    builtins::ActivationType,
+use {
+    solana_runtime::{
+        bank::{Builtin, Builtins},
+        builtins::ActivationType,
+    },
+    solana_sdk::{feature_set, pubkey::Pubkey},
 };
-use solana_sdk::{feature_set, pubkey::Pubkey};
 
 macro_rules! to_builtin {
     ($b:expr) => {
@@ -16,7 +18,12 @@ fn genesis_builtins(bpf_jit: bool) -> Vec<Builtin> {
     // !x86_64: https://github.com/qmonnet/rbpf/issues/48
     // Windows: https://github.com/solana-labs/rbpf/issues/217
     #[cfg(any(not(target_arch = "x86_64"), target_family = "windows"))]
-    let bpf_jit = false;
+    let bpf_jit = {
+        if bpf_jit {
+            info!("BPF JIT is not supported on this target");
+        }
+        false
+    };
 
     vec![
         to_builtin!(solana_bpf_loader_deprecated_program!()),
