@@ -1,10 +1,11 @@
-use std::collections::HashMap;
-
-use crate::leader_schedule::LeaderSchedule;
-use solana_runtime::bank::Bank;
-use solana_sdk::{
-    clock::{Epoch, Slot, NUM_CONSECUTIVE_LEADER_SLOTS},
-    pubkey::Pubkey,
+use {
+    crate::leader_schedule::LeaderSchedule,
+    solana_runtime::bank::Bank,
+    solana_sdk::{
+        clock::{Epoch, Slot, NUM_CONSECUTIVE_LEADER_SLOTS},
+        pubkey::Pubkey,
+    },
+    std::collections::HashMap,
 };
 
 /// Return the leader schedule for the given epoch.
@@ -12,7 +13,10 @@ pub fn leader_schedule(epoch: Epoch, bank: &Bank) -> Option<LeaderSchedule> {
     bank.epoch_staked_nodes(epoch).map(|stakes| {
         let mut seed = [0u8; 32];
         seed[0..8].copy_from_slice(&epoch.to_le_bytes());
-        let mut stakes: Vec<_> = stakes.into_iter().collect();
+        let mut stakes: Vec<_> = stakes
+            .iter()
+            .map(|(pubkey, stake)| (*pubkey, *stake))
+            .collect();
         sort_stakes(&mut stakes);
         LeaderSchedule::new(
             &stakes,
@@ -75,9 +79,11 @@ fn sort_stakes(stakes: &mut Vec<(Pubkey, u64)>) {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
-    use solana_runtime::genesis_utils::{
-        bootstrap_validator_stake_lamports, create_genesis_config_with_leader,
+    use {
+        super::*,
+        solana_runtime::genesis_utils::{
+            bootstrap_validator_stake_lamports, create_genesis_config_with_leader,
+        },
     };
 
     #[test]
@@ -88,7 +94,11 @@ mod tests {
                 .genesis_config;
         let bank = Bank::new(&genesis_config);
 
-        let pubkeys_and_stakes: Vec<_> = bank.staked_nodes().into_iter().collect();
+        let pubkeys_and_stakes: Vec<_> = bank
+            .staked_nodes()
+            .iter()
+            .map(|(pubkey, stake)| (*pubkey, *stake))
+            .collect();
         let seed = [0u8; 32];
         let leader_schedule = LeaderSchedule::new(
             &pubkeys_and_stakes,
